SoftMarginRankingLoss
=====================

.. currentmodule:: pykeen.losses

.. autoclass:: SoftMarginRankingLoss
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~SoftMarginRankingLoss.hpo_default

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default
